Coverage for modules/box__bizhelp/page/forms.py: 100%

# Coverage for modules/box__bizhelp/page/forms.py : 100%

## 9 statements

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 from flask_wtf import FlaskForm

2 from wtforms import StringField

3 from wtforms import TextAreaField

4 from wtforms.validators import DataRequired

5

6 from shopyo.api.validators import verify_slug

7

8# from wtforms.validators import Length

9# from wtforms.fields import EmailField

10

11

12 class PageForm(FlaskForm):

13

14 content = TextAreaField(

15 "Content",

16 [],

17 render_kw={

18 "class": "form-control",

19 "rows": "20",

20 "autocomplete": "off",

21 },

22 )

23 slug = StringField(

24 "Slug",

25 [DataRequired(), verify_slug],

26 render_kw={"class": "form-control", "autocomplete": "off"},

27 )

28 title = StringField(

29 "Title",

30 [DataRequired()],

31 render_kw={"class": "form-control", "autocomplete": "off"},

32 )